<?php
/* banner-php */
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function homeradar_body_classes( $classes ) {
	// Add class for fullscreen and fixed footer

    $classes[] = 'body-homeradar';

	$classes[] = 'folio-archive-'.homeradar_get_option('folio_layout');


    if(post_password_required()) $classes[] = 'is-protected-page';

	// Add class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Add class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add class if we're viewing the Customizer for easier styling of theme options.
	if ( is_customize_preview() ) {
		$classes[] = 'homeradar-customizer';
	}

	// Add class on front page.
	if ( is_front_page() && 'posts' !== get_option( 'show_on_front' ) ) {
		$classes[] = 'homeradar-front-page';
	}
    if( homeradar_is_woocommerce_activated() ){
        if( $shop_columns = homeradar_get_option('shop_columns') ){
            $classes[] = 'woo-'.esc_attr($shop_columns);
        }
        if( $shop_columns_tablet = homeradar_get_option('shop_columns_tablet') ){
            $classes[] = 'woo-tablet-'.esc_attr($shop_columns_tablet);
        }
    }
        

	return $classes;
}
add_filter( 'body_class', 'homeradar_body_classes' );



/**
 * Return attachment image link by using wp_get_attachment_image_src function
 *
 */
function homeradar_get_attachment_thumb_link( $id, $size = 'thumbnail' ){
    $image_attributes = wp_get_attachment_image_src( $id, $size, false );
    if ( $image_attributes ) {
        return $image_attributes[0];
    }
    return '';
}

/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for content images.
 *
 * @since HomeRadar 1.2
 *
 * @param string $sizes A source size value for use in a 'sizes' attribute.
 * @param array  $size  Image size. Accepts an array of width and height
 *                      values in pixels (in that order).
 * @return string A source size value for use in a content image 'sizes' attribute.
 */
function homeradar_content_image_sizes_attr( $sizes, $size ) {
    return '';
}

add_filter( 'wp_calculate_image_sizes', 'homeradar_content_image_sizes_attr', 10, 2 );


if(!function_exists('homeradar_get_template_part')){
    /**
     * Load a template part into a template
     *
     * Makes it easy for a theme to reuse sections of code in a easy to overload way
     * for child themes.
     *
     * Includes the named template part for a theme or if a name is specified then a
     * specialised part will be included. If the theme contains no {slug}.php file
     * then no template will be included.
     *
     * The template is included using require, not require_once, so you may include the
     * same template part multiple times.
     *
     * For the $name parameter, if the file is called "{slug}-special.php" then specify
     * "special".
      * For the var parameter, simple create an array of variables you want to access in the template
     * and then access them e.g. 
     * 
     * array("var1=>"Something","var2"=>"Another One","var3"=>"heres a third";
     * 
     * becomes
     * 
     * $var1, $var2, $var3 within the template file.
     *
     *
     * @param string $slug The slug name for the generic template.
     * @param string $name The name of the specialised template.
     * @param array $vars The list of variables to carry over to the template
     * @author CTHthemes 
     * @ref http://www.zmastaa.com/2015/02/06/php-2/wordpress-passing-variables-get_template_part
     * @ref http://keithdevon.com/passing-variables-to-get_template_part-in-wordpress/
     */
    function homeradar_get_template_part( $xxxslug, $xxxname = null, $xxxvars = null ) {
        $xxxtemplate = "{$xxxslug}.php";
        $xxxname      = (string) $xxxname;
        if ( '' !== $xxxname ) {
            $xxxtemplate = "{$xxxslug}-{$xxxname}.php";
        }
        $xxxlocated = locate_template($xxxtemplate, false);
        if($xxxlocated !== ''){
            /*
             * This use of extract() cannot be removed. There are many possible ways that
             * templates could depend on variables that it creates existing, and no way to
             * detect and deprecate it.
             *
             * Passing the EXTR_SKIP flag is the safest option, ensuring globals and
             * function variables cannot be overwritten.
             */
            // phpcs:ignore WordPress.PHP.DontExtract.extract_extract
            if(isset($xxxvars)) extract($xxxvars, EXTR_SKIP);
            include $xxxlocated;
        }
    }
}
if(!function_exists('homeradar_get_the_password_form')){
    function homeradar_get_the_password_form($post = 0){
        $post = get_post( $post );
        $label = 'pwbox-' . ( empty($post->ID) ? rand() : $post->ID );
        $output = '<p>' . esc_html__( 'This content is password protected. To view it please enter your password below:' , 'homeradar') . '</p><form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form" method="post"><input name="post_password" id="' . $label . '" type="password" size="20" /><button type="submit" class="search-submit color2-bg"><i class="fal fa-eye"></i></button></form>
        ';

        return $output ;
    }
}
add_filter('the_password_form','homeradar_get_the_password_form' );

if( !function_exists( 'homeradar_get_kirki_dynamic_css' ) ){
    function homeradar_get_kirki_dynamic_css($styles){
        if( homeradar_get_option( 'use_custom_color', false ) ){
            return $styles;
        }else{
            return '';
        }
    }
}
add_filter('kirki/homeradar_configs/dynamic_css','homeradar_get_kirki_dynamic_css' );


/**
 * Modify category count format
 *
 * @since HomeRadar 1.0
 */
function homeradar_custom_category_count_widget($output) {
    return preg_replace("/<\/a>\s*\(([\d]+)\)\s*</", '</a><span>$1</span><', $output);
    
}
add_filter('wp_list_categories', 'homeradar_custom_category_count_widget');

/**
 * Modify archive count format
 *
 * @since HomeRadar 1.0
 */
function homeradar_custom_archives_count_widget($link_html) {
    return preg_replace("/<\/a>\s*&nbsp;\s*\(([\d]+)\)\s*</", '</a><span>$1</span><', $link_html);
}
add_filter('get_archives_link', 'homeradar_custom_archives_count_widget');


function homeradar_relative_protocol_url(){
    return is_ssl() ? 'https' : 'http';
}

/**
 * Reorder comment field output
 *
 */
function homeradar_remove_comment_field($string) {
    
    return '';
}
add_filter( 'comment_form_field_comment', 'homeradar_remove_comment_field' );

/**
 * Then add comment field after
 *
 */
function homeradar_add_comment_field_after() {
    $req = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );
    echo '<textarea name="comment" id="comment" placeholder="'.esc_attr__('Your Review:','homeradar').'" cols="40" rows="3" '.$aria_req.'></textarea>';
}
add_filter( 'comment_form_after_fields', 'homeradar_add_comment_field_after' );
add_filter( 'comment_form_logged_in_after', 'homeradar_add_comment_field_after' );


function homeradar_kses_allowed_html($tags, $context) {
  switch($context) {
    case 'cth': 
      $tags = array( 
        'a'          => array(
            'href'  => true,
            'title' => true,
            'class' => true,
        ),
        'abbr'       => array(
            'title' => true,
        ),
        'acronym'    => array(
            'title' => true,
        ),
        'b'          => array(),
        'blockquote' => array(
            'cite' => true,
        ),
        'cite'       => array(),
        'code'       => array(),
        'del'        => array(
            'datetime' => true,
        ),
        'em'         => array(),
        'i'          => array(),
        'q'          => array(
            'cite' => true,
        ),
        's'          => array(),
        'strike'     => array(),
        'strong'     => array(),
        'div'        => array(
            'align'    => true,
            'dir'      => true,
            'lang'     => true,
            'xml:lang' => true,
            'class' => true,
        ),
        'h1'         => array(
            'align' => true,
            'class' => true,
        ),
        'h2'         => array(
            'align' => true,
            'class' => true,
        ),
        'h3'         => array(
            'align' => true,
            'class' => true,
        ),
        'h4'         => array(
            'align' => true,
            'class' => true,
        ),
        'h5'         => array(
            'align' => true,
            'class' => true,
        ),
        'h6'         => array(
            'align' => true,
            'class' => true,
        ),
        'p'          => array(
            'align'    => true,
            'dir'      => true,
            'lang'     => true,
            'xml:lang' => true,
            'class' => true,
        ),
        'ul'         => array(
            'type' => true,
            'class' => true,
        ),
        'ol'         => array(
            'start'    => true,
            'type'     => true,
            'reversed' => true,
            'class' => true,
        ),
        'li'         => array(
            'align' => true,
            'value' => true,
            'class' => true,
        ),
        'span'       => array(
            'dir'      => true,
            'align'    => true,
            'lang'     => true,
            'xml:lang' => true,
            'class'     => true,
        ),
      );
      return $tags;
    default: 
      return $tags;
  }
}

add_filter( 'wp_kses_allowed_html', 'homeradar_kses_allowed_html', 10, 2);

